@@ -4,11 +4,14 @@ HTML renderer
 The contents of this module are internal to fpdf2, and not part of the public API.
 They may change at any time without prior warning or any deprecation period,
 in non-backward-compatible ways.
+
+Usage documentation at: <https://py-pdf.github.io/fpdf2/HTML.html>
 """
 
 from html.parser import HTMLParser
 from string import ascii_lowercase, ascii_uppercase
 import logging, re, warnings
+from typing import Optional, Union
 
 from .deprecation import get_stack_level
 from .drawing import color_from_hex_string, convert_to_device_color
@@ -19,8 +22,10 @@ from .table import Table
 from .util import get_scale_factor, int2roman
 
 LOGGER = logging.getLogger(__name__)
-BULLET_WIN1252 = "\x95"  # BULLET character in Windows-1252 encoding
-DEGREE_WIN1252 = "\xb0"
+MESSAGE_WAITING_WIN1252 = "\x95"  # MESSAGE WAITING character in Windows-1252 encoding
+BULLET_UNICODE = "•"  # U+2022
+DEGREE_SIGN_WIN1252 = "\xb0"  # DEGREE SIGN character in Windows-1252 encoding
+RING_OPERATOR_UNICODE = "∘"  # U+2218
 HEADING_TAGS = ("title", "h1", "h2", "h3", "h4", "h5", "h6")
 # Some of the margin values below are fractions, in order to be fully backward-compatible,
 # and due to the _scale_units() conversion performed in HTML2FPDF constructor below.
@@ -40,7 +45,7 @@ DEFAULT_TAG_STYLES = {
     "u": FontFace(emphasis="UNDERLINE"),
     # Block tags are TextStyle instances :
     "blockquote": TextStyle(color="#64002d", t_margin=3, b_margin=3),
-    "center": TextStyle(t_margin=4 + 7 / 30),
+    "center": TextStyle(t_margin=4 + 7 / 30, l_margin=Align.C),
     "dd": TextStyle(l_margin=10),
     "dt": TextStyle(font_style="B", t_margin=4 + 7 / 30),
     "title": TextStyle(  # Only rendered if render_title_tag=True
@@ -316,7 +321,7 @@ class HTML2FPDF(HTMLParser):
         li_tag_indent=None,
         dd_tag_indent=None,
         table_line_separators=False,
-        ul_bullet_char=BULLET_WIN1252,
+        ul_bullet_char="disc",
         li_prefix_color=(190, 0, 0),
         heading_sizes=None,
         pre_code_font=None,
@@ -328,7 +333,7 @@ class HTML2FPDF(HTMLParser):
     ):
         """
         Args:
-            pdf (FPDF): an instance of `fpdf.FPDF`
+            pdf (fpdf.fpdf.FPDF): an instance of `FPDF`
             image_map (function): an optional one-argument function that map `<img>` "src" to new image URLs
             li_tag_indent (int): [**DEPRECATED since v2.7.9**]
                 numeric indentation of `<li>` elements - Set `tag_styles` instead
@@ -336,6 +341,7 @@ class HTML2FPDF(HTMLParser):
                 numeric indentation of `<dd>` elements - Set `tag_styles` instead
             table_line_separators (bool): enable horizontal line separators in `<table>`. Defaults to `False`.
             ul_bullet_char (str): bullet character preceding `<li>` items in `<ul>` lists.
+                You can also specify special bullet names like `"circle"` or `"disc"` (the default).
                 Can also be configured using the HTML `type` attribute of `<ul>` tags.
             li_prefix_color (tuple, str, fpdf.drawing.DeviceCMYK, fpdf.drawing.DeviceGray, fpdf.drawing.DeviceRGB): color for bullets
                 or numbers preceding `<li>` tags. This applies to both `<ul>` & `<ol>` lists.
@@ -377,23 +383,25 @@ class HTML2FPDF(HTMLParser):
             style=self.font_emphasis.style,
         )
         self.style_stack = []  # list of FontFace
-        self.h = pdf.font_size_pt / pdf.k
         self._page_break_after_paragraph = False
-        self._pre_formatted = False  # preserve whitespace while True.
-        # nothing written yet to <pre>, remove one initial nl:
-        self._pre_started = False
         self.follows_trailing_space = False  # The last write has ended with a space.
         self.follows_heading = False  # We don't want extra space below a heading.
-        self.href = ""
-        self.align = ""
-        self.indent = 0
-        self.line_height_stack = []
-        self.ol_type = []  # when inside a <ol> tag, can be "a", "A", "i", "I" or "1"
-        self.bullet = []
+        self.align: Optional[Union[float, Align]] = None
         self.heading_level = None
         self._tags_stack = []
         self._column = self.pdf.text_columns(skip_leading_spaces=True)
         self._paragraph = self._column.paragraph()
+        # <pre>-related properties:
+        self._pre_formatted = False  # preserve whitespace while True.
+        # nothing written yet to <pre>, remove one initial nl:
+        self._pre_started = False
+        # <a>-related properties:
+        self.href = ""
+        # <ul>/<ol>-related properties:
+        self.indent = 0
+        self.line_height_stack = []
+        self.ol_type = {}  # when inside a <ol> tag, can be "a", "A", "i", "I" or "1"
+        self.bullet = []
         # <title>-related properties:
         self.render_title_tag = render_title_tag
         self._in_title = False
@@ -505,7 +513,7 @@ class HTML2FPDF(HTMLParser):
 
     def _new_paragraph(
         self,
-        align=None,
+        align: Optional[Union[float, Align]] = None,
         line_height=1.0,
         top_margin=0,
         bottom_margin=0,
@@ -515,7 +523,7 @@ class HTML2FPDF(HTMLParser):
         # Note that currently top_margin is ignored if bullet is also provided,
         # due to the behaviour of TextRegion._render_column_lines()
         self._end_paragraph()
-        self.align = align or ""
+        self.align = align
         if isinstance(indent, Align):
             # Explicit alignment takes priority over alignment provided as TextStyle.l_margin:
             if not self.align:
@@ -536,7 +544,7 @@ class HTML2FPDF(HTMLParser):
         self.follows_heading = False
 
     def _end_paragraph(self):
-        self.align = ""
+        self.align = None
         if not self._paragraph:
             return
         self._column.end_paragraph()
@@ -618,10 +626,22 @@ class HTML2FPDF(HTMLParser):
                 emphasis |= TextEmphasis.I
             if self.td_th.get("U"):
                 emphasis |= TextEmphasis.U
+            font_family = (
+                self.font_family if self.font_family != self.pdf.font_family else None
+            )
+            font_size_pt = (
+                self.font_size_pt
+                if self.font_size_pt != self.pdf.font_size_pt
+                else None
+            )
             font_style = None
-            if bgcolor or emphasis:
+            if font_family or emphasis or font_size_pt or bgcolor:
                 font_style = FontFace(
-                    emphasis=emphasis, fill_color=bgcolor, color=self.pdf.text_color
+                    family=font_family,
+                    emphasis=emphasis,
+                    size_pt=font_size_pt,
+                    color=self.pdf.text_color,
+                    fill_color=bgcolor,
                 )
             self.table_row.cell(
                 text=data,
@@ -731,6 +751,14 @@ class HTML2FPDF(HTMLParser):
                 except ValueError:
                     line_height = None
             tag_style = self.tag_styles[tag]
+            if tag_style.color is not None and tag_style.color != self.font_color:
+                self.font_color = tag_style.color
+            if tag_style.family is not None and tag_style.family != self.font_family:
+                self.font_family = tag_style.family
+            if tag_style.size_pt is not None and tag_style.size_pt != self.font_size_pt:
+                self.font_size_pt = tag_style.size_pt
+            if tag_style.emphasis:
+                self.font_emphasis |= tag_style.emphasis
             self._new_paragraph(
                 align=align,
                 line_height=line_height,
@@ -768,10 +796,12 @@ class HTML2FPDF(HTMLParser):
                 # "color" attributes are not valid in HTML,
                 # but we support it for backward compatibility:
                 self.font_color = color_as_decimal(attrs["color"])
-            elif tag_style.color:
+            elif tag_style.color is not None and tag_style.color != self.font_color:
                 self.font_color = tag_style.color
-            self.font_family = tag_style.family or self.font_family
-            self.font_size_pt = tag_style.size_pt or self.font_size_pt
+            if tag_style.family is not None and tag_style.family != self.font_family:
+                self.font_family = tag_style.family
+            if tag_style.size_pt is not None and tag_style.size_pt != self.font_size_pt:
+                self.font_size_pt = tag_style.size_pt
             if tag_style.emphasis:
                 self.font_emphasis |= tag_style.emphasis
         if tag in (
@@ -815,7 +845,6 @@ class HTML2FPDF(HTMLParser):
                     # cf. https://github.com/py-pdf/fpdf2/pull/1217#discussion_r1666643777
                     self.follows_heading = True
                 self._new_paragraph(
-                    align="C" if tag == "center" else None,
                     line_height=(
                         self.line_height_stack[-1] if self.line_height_stack else None
                     ),
@@ -825,9 +854,7 @@ class HTML2FPDF(HTMLParser):
                 )
         if tag == "ul":
             self.indent += 1
-            bullet_char = (
-                ul_prefix(attrs["type"]) if "type" in attrs else self.ul_bullet_char
-            )
+            bullet_char = attrs.get("type", self.ul_bullet_char)
             self.bullet.append(bullet_char)
             line_height = css_style.get("line-height", attrs.get("line-height"))
             # "line-height" attributes are not valid in HTML,
@@ -855,7 +882,7 @@ class HTML2FPDF(HTMLParser):
             self.indent += 1
             start = int(attrs["start"]) if "start" in attrs else 1
             self.bullet.append(start - 1)
-            self.ol_type.append(attrs.get("type", "1"))
+            self.ol_type[self.indent] = attrs.get("type", "1")
             line_height = css_style.get("line-height", attrs.get("line-height"))
             # "line-height" attributes are not valid in HTML,
             # but we support it for backward compatibility,
@@ -886,10 +913,12 @@ class HTML2FPDF(HTMLParser):
             else:
                 # Allow <li> to be used outside of <ul> or <ol>.
                 bullet = self.ul_bullet_char
+            if not isinstance(bullet, int):
+                bullet = ul_prefix(bullet, self.pdf.is_ttf_font)
             if not isinstance(bullet, str):
                 bullet += 1
                 self.bullet[self.indent - 1] = bullet
-                ol_type = self.ol_type[self.indent - 1]
+                ol_type = self.ol_type[self.indent]
                 bullet = f"{ol_prefix(ol_type, bullet)}."
             tag_style = self.tag_styles[tag]
             self._ln(tag_style.t_margin)
@@ -920,6 +949,7 @@ class HTML2FPDF(HTMLParser):
             if "face" in attrs:
                 self.font_family = attrs.get("face").lower()
         if tag == "table":
+            self._end_paragraph()
             width = css_style.get("width", attrs.get("width"))
             if width:
                 if width[-1] == "%":
@@ -945,7 +975,7 @@ class HTML2FPDF(HTMLParser):
                 self.pdf,
                 align=align,
                 borders_layout=borders_layout,
-                line_height=self.h * self.TABLE_LINE_HEIGHT,
+                line_height=self.font_size_pt / self.pdf.k * self.TABLE_LINE_HEIGHT,
                 width=width,
                 padding=padding,
                 gutter_width=spacing,
@@ -1007,8 +1037,8 @@ class HTML2FPDF(HTMLParser):
                 self.td_th["inserted"] = True
                 return
             x = self.pdf.get_x()
-            if self.align and self.align[0].upper() == "C":
-                x = Align.C
+            if self.align:
+                x = self.align
             self.pdf.image(
                 self.image_map(attrs["src"]), x=x, w=width, h=height, link=self.href
             )
@@ -1061,7 +1091,7 @@ class HTML2FPDF(HTMLParser):
                 self.font_emphasis = font_face.emphasis
                 self.font_color = font_face.color
             self._end_paragraph()
-            self.align = ""
+            self.align = None
         if tag in HEADING_TAGS:
             self.heading_level = None
             if self.style_stack:
@@ -1099,15 +1129,15 @@ class HTML2FPDF(HTMLParser):
                 self._end_paragraph()
         if tag in ("ul", "ol"):
             self._end_paragraph()
-            self.indent -= 1
             if tag == "ol":
-                self.ol_type.pop()
+                self.ol_type.pop(self.indent)
+            self.indent -= 1
             self.line_height_stack.pop()
             self.bullet.pop()
         if tag == "table":
             self.table.render()
             self.table = None
-            self._ln(self.h)
+            self._ln()
         if tag == "tr":
             self.tr = None
             self.table_row = None
@@ -1209,11 +1239,11 @@ def _scale_units(pdf, in_tag_styles):
     return out_tag_styles
 
 
-def ul_prefix(ul_type):
-    if ul_type == "circle":
-        return DEGREE_WIN1252
+def ul_prefix(ul_type, is_ttf_font):
     if ul_type == "disc":
-        return BULLET_WIN1252
+        return BULLET_UNICODE if is_ttf_font else MESSAGE_WAITING_WIN1252
+    if ul_type == "circle":
+        return RING_OPERATOR_UNICODE if is_ttf_font else DEGREE_SIGN_WIN1252
     if len(ul_type) == 1:
         return ul_type
     raise NotImplementedError(f"Unsupported type: {ul_type}")
