@@ -5,6 +5,8 @@ automatic line wrapping.
 The contents of this module are internal to fpdf2, and not part of the public API.
 They may change at any time without prior warning or any deprecation period,
 in non-backward-compatible ways.
+
+Usage documentation at: <https://py-pdf.github.io/fpdf2/LineBreaks.html>
 """
 
 from numbers import Number
@@ -424,7 +426,7 @@ class TextLine(NamedTuple):
         directional_runs = []
         direction = None
         for fragment in self.fragments:
-            if fragment.fragment_direction == direction:
+            if direction is not None and fragment.fragment_direction == direction:
                 directional_runs[-1].append(fragment)
             else:
                 directional_runs.append([fragment])
