@@ -3,6 +3,8 @@ from filecmp import cmp
 import fpdf
 import pytest
 
+from test.conftest import assert_same_file
+
 
 def test_repeated_calls_to_output(tmp_path):
     pdf = fpdf.FPDF()
@@ -16,7 +18,7 @@ def test_deprecation_warning(tmp_path):
     with pytest.warns(DeprecationWarning) as record:
         pdf.output(tmp_path / "empty.pdf", "F")
     assert len(record) == 1
-    assert record[0].filename == __file__
+    assert_same_file(record[0].filename, __file__)
 
 
 def test_save_to_absolute_path(tmp_path):
