@@ -2,6 +2,6 @@ from fpdf import FPDF
 
 pdf = FPDF()
 pdf.add_page()
-pdf.set_font("helvetica", "B", 16)
+pdf.set_font("helvetica", style="B", size=16)
 pdf.cell(40, 10, "Hello World!")
 pdf.output("tuto1.pdf")
